# petisco 🍪  



<div align="center">
    <img src="https://github.com/alice-biometrics/custom-emojis/blob/master/images/petisco.png?raw=true" style="width: 60%">


 [Alice] | [Getting Started] | [Documentation] | [Source Code] | [Examples]

 [![version](https://img.shields.io/github/release/alice-biometrics/petisco/all.svg)](https://github.com/alice-biometrics/petisco/releases) 
[![ci](https://github.com/alice-biometrics/petisco/workflows/ci/badge.svg)](https://github.com/alice-biometrics/petisco/actions) 
[![pypi](https://img.shields.io/pypi/dm/petisco)](https://pypi.org/project/petisco/) 
[![codecov](https://codecov.io/gh/alice-biometrics/petisco/branch/main/graph/badge.svg?token=YHXAYKX0VO)](https://codecov.io/gh/alice-biometrics/petisco)
[![license](https://img.shields.io/github/license/alice-biometrics/petisco.svg)](https://github.com/alice-biometrics/petisco/blob/main/LICENSE)
[![versions](https://img.shields.io/pypi/pyversions/petisco.svg)](https://github.com/alice-biometrics/petisco)
[![Ruff](https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/astral-sh/ruff/main/assets/badge/v2.json)](https://github.com/astral-sh/ruff)
[![Pydantic v2](https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/pydantic/pydantic/main/docs/badge/v2.json)](https://docs.pydantic.dev/latest/contributing/#badges)

</div>

[Alice]: https://alicebiometrics.com/
[Getting Started]: https://alice-biometrics.github.io/petisco/getting_started/
[Documentation]: https://alice-biometrics.github.io/petisco/
[Source Code]: ./petisco
[Examples]: ./examples

---

## What is petisco? 🍪

petisco is a framework for helping Python developers to build clean Applications in Python.

## How could petisco help me? 🍪

petisco provides several handy classes to help you on defining your domain with hexagonal architecture, event streaming and CQRS.

## Installation 💻

```console
pip install petisco
```

Installation with Extras

```console
pip install petisco[fastapi,sqlalchemy,elastic,elastic-apm,rabbitmq,slack,redis]
```

## Contribute

We'd love you to contribute to *petisco* 🥳🥳🥳🥳🥳🥳️️!

For more information, check our [documentation](https://alice-biometrics.github.io/petisco/contributing/)

## Contact 📬

<support@alicebiometrics.com>
